@@ -1,6 +1,7 @@
 from torch import nn
-from ..generic.transformer import FFTransformersBlock
-from ..generic.pos_encoding import PositionalEncoding
+
+from TTS.tts.layers.generic.pos_encoding import PositionalEncoding
+from TTS.tts.layers.generic.transformer import FFTransformerBlock
 
 
 class DurationPredictor(nn.Module):
@@ -8,7 +9,7 @@ class DurationPredictor(nn.Module):
         super().__init__()
         self.embed = nn.Embedding(num_chars, hidden_channels)
         self.pos_enc = PositionalEncoding(hidden_channels, dropout_p=0.1)
-        self.FFT = FFTransformersBlock(hidden_channels, num_heads, hidden_channels_ffn, 2, 0.1)
+        self.FFT = FFTransformerBlock(hidden_channels, num_heads, hidden_channels_ffn, 2, 0.1)
         self.out_layer = nn.Conv1d(hidden_channels, 1, 1)
 
     def forward(self, text, text_lengths):
